@@ -1,6 +1,6 @@
 package Treex;
-{
-  $Treex::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::VERSION = '0.06441';
 }
 use strict;
 use warnings;
@@ -16,7 +16,7 @@ Treex - Natural Language Processing framework
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.06441
 
 =head1 INTRODUCTION
 
@@ -138,8 +138,6 @@ distributions are hoped to appear soon too.
 
 =head1 REFERENCES
 
-L<Treex website|http://ufal.mff.cuni.cz/treex>
-
 Selected TectoMT/Treex-related publications:
 
 - Žabokrtský Zdeněk, Ptáček Jan, Pajas Petr:
@@ -200,4 +198,4 @@ Daniel Zeman
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
