@@ -1,10 +1,12 @@
 package Treex::Block::Read::BaseReader;
 BEGIN {
-  $Treex::Block::Read::BaseReader::VERSION = '0.05222';
+  $Treex::Block::Read::BaseReader::VERSION = '0.06441';
 }
 use Moose;
 use Treex::Core::Common;
+use File::Slurp;
 with 'Treex::Core::DocumentReader';
+use Treex::Core::Document;
 
 sub next_document {
     my ($self) = @_;
@@ -18,7 +20,7 @@ has filenames => (
     is            => 'ro',
     lazy_build    => 1,
     documentation => 'array of filenames to be loaded;'
-        . ' automatically initialized from the attribute "from"',
+        . ' automatically initialized from the attributes "from" and "filelist"',
 );
 
 has from => (
@@ -27,6 +29,12 @@ has from => (
     documentation => 'space or comma separated list of filenames to be loaded',
 );
 
+has filelist => (
+    isa           => 'Str',
+    is            => 'ro',
+    documentation => 'a file that contains the list of filenames to be loaded, one per line',
+);
+
 has file_stem => (
     isa           => 'Str',
     is            => 'ro',
@@ -52,8 +60,31 @@ has _file_numbers => ( is => 'rw', default => sub { {} } );
 
 sub _build_filenames {
     my $self = shift;
-    log_fatal "Parameter 'from' must be defined!" if !defined $self->from;
-    return [split /[ ,]+/, $self->from ];
+
+    log_fatal "Parameters 'from' or 'filelist' must be defined!" if !defined $self->from && !defined $self->filelist;
+
+    my $filenames = [];
+
+    # add all files in the 'from' parameter to the list (avoid adding STDIN if filelist is set)
+    if ( $self->from && ( !$self->filelist || $self->from ne '-' ) ) {
+        push @{$filenames}, split( /[ ,]+/, $self->from );
+    }
+
+    # add all files from the filelist to the list
+    if ( $self->filelist ) {
+        my @list = read_file( $self->filelist );
+        log_fatal 'File list ' . $self->filelist . ' cannot be loaded!' if @list == 1 && !defined( $list[0] );
+        @list = map {
+            local $_ = $_;
+            $_ =~ s/\s*\r?\n$//;
+            $_ =~ s/^\s*//;
+            $_
+        } @list;    # remove EOL chars, trim
+        push @{$filenames}, @list;
+    }
+
+    # return the resulting list
+    return $filenames;
 }
 
 sub current_filename {
@@ -90,6 +121,7 @@ sub new_document {
     log_fatal "next_filename() must be called before new_document()" if !defined $path;
     my ( $volume, $dirs, $file ) = File::Spec->splitpath($path);
     my ( $stem, $extension ) = $file =~ /([^.]+)(\..+)?/;
+    $stem =~ s/^-$/noname/;
     my %args = ( file_stem => $stem, loaded_from => $path );
     if ( defined $dirs ) {
         $args{path} = $volume . $dirs;
@@ -136,12 +168,12 @@ Treex::Block::Read::BaseReader - abstract ancestor for document readers
 
 =head1 VERSION
 
-version 0.05222
+version 0.06441
 
 =head1 DESCRIPTION
 
 This class serves as an common ancestor for document readers,
-that have parameter C<from> with a space or comma separated list of filenames
+that have a parameter C<from> with a space or comma separated list of filenames
 to be loaded.
 It is designed to implement the L<Treex::Core::DocumentReader> interface.
 
@@ -152,16 +184,20 @@ and you can use C<next_filename> and C<new_document> methods.
 
 =over
 
-=item from (required)
+=item from (required, if C<filelist> is not set)
 
-space or comma separated list of filenames, or "-" for STDIN
+space or comma separated list of filenames, or C<-> for STDIN
 (If you use this method via API you can specify C<filenames> instead.)
 
+=item filelist (required, if C<from> is not set)
+
+path to a file that contains a list of files to be read (one per line) 
+
 =item file_stem (optional)
 
 How to name the loaded documents.
-This will attribute will be saved to the same-named
-attdibute in documents and it will be used in documents writers
+This attribute will be saved to the same-named
+attribute in documents and it will be used in document writers
 to decide where to save the files.
 
 =item filenames (internal)
@@ -188,7 +224,7 @@ returns the next filename (full path) to be loaded
 =item new_document($load_from?)
 
 Returns a new empty document with pre-filled attributes
-loaded_from, file_stem, file_number and path
+C<loaded_from>, C<file_stem>, C<file_number> and C<path>
 which are guessed based on C<current_filename>.
 
 =item current_filename
@@ -200,14 +236,14 @@ returns the last filename returned by C<next_filename>
 Is the document that will be returned by C<next_document>
 supposed to be processed by this job?
 This is relevant only in parallel processing,
-where each job has different C<$jobnumber> assigned.
+where each job has a different C<$jobnumber> assigned.
 
 =item number_of_documents
 
 Returns the number of documents that will be read by this reader.
-If C<is_one_doc_per_file> returns true, then the number of documents
+If C<is_one_doc_per_file> returns C<true>, then the number of documents
 equals the number of files given in C<from>.
-Otherwise, this method returns undef.
+Otherwise, this method returns C<undef>.
 
 =back
 
