@@ -1,6 +1,6 @@
 package Treex::Block::Read::BaseTextReader;
 BEGIN {
-  $Treex::Block::Read::BaseTextReader::VERSION = '0.05222';
+  $Treex::Block::Read::BaseTextReader::VERSION = '0.06441';
 }
 use Moose;
 use Treex::Core::Common;
@@ -13,6 +13,7 @@ has '+from' => ( default => '-' );
 has language      => ( isa => 'LangCode', is => 'ro', required => 1 );
 has lines_per_doc => ( isa => 'Int',      is => 'ro', default  => 0 );
 has merge_files   => ( isa => 'Bool',     is => 'ro', default  => 0 );
+has encoding      => ( isa => 'Str',      is => 'ro', default  => 'utf8' );
 
 has _current_fh => ( is => 'rw' );
 
@@ -28,8 +29,12 @@ sub next_filehandle {
     my ($self) = @_;
     my $filename = $self->next_filename();
     return if !defined $filename;
-    return \*STDIN if $filename eq '-';
-    open my $FH, '<:utf8', $filename or log_fatal "Can't open $filename: $!";
+    if ( $filename eq '-' ) {
+        binmode STDIN, $self->encoding;
+        return \*STDIN;
+    }
+    my $mode = '<:' . $self->encoding;
+    open my $FH, $mode, $filename or log_fatal "Can't open $filename: $!";
     return $FH;
 }
 
@@ -75,7 +80,7 @@ Treex::Block::Read::BaseTextReader - abstract ancestor for document readers
 
 =head1 VERSION
 
-version 0.05222
+version 0.06441
 
 =head1 DESCRIPTION
 
@@ -104,6 +109,10 @@ Merge the content of all files (specified in C<from> attribute) into one stream.
 Useful in combination with C<lines_per_doc> to get equally-sized documents
 even from non-equally-sized files.
 
+=item encoding
+
+Whan is the encoding of the input files. E.g. C<utf8> (the default), C<cp1250> etc.
+
 =back
 
 =head1 METHODS
