@@ -1,6 +1,6 @@
 package Treex::Core::BundleZone;
 BEGIN {
-  $Treex::Core::BundleZone::VERSION = '0.05222';
+  $Treex::Core::BundleZone::VERSION = '0.06441';
 }
 
 use Moose;
@@ -26,49 +26,31 @@ sub _set_bundle {
 
 sub get_bundle {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->get_attr('_bundle');
 }
 
 sub get_document {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->get_bundle->get_document;
 }
 
 sub create_atree {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->create_tree('a');
 }
 
 sub create_ttree {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->create_tree('t');
 }
 
 sub create_ntree {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->create_tree('n');
 }
 
 sub create_ptree {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->create_tree('p');
 }
 
@@ -112,10 +94,10 @@ sub remove_tree {
         { isa => 'Layer' },
     );
 
-    # disconnect all nodes ($tree_root->disconnect does not work, in order to not be used by users)
+    # remove all nodes ($tree_root->remove does not work, in order to not be used by users)
     my $tree_root = $self->get_tree($layer);
     foreach my $child ( $tree_root->get_children() ) {
-        $child->disconnect();
+        $child->remove();
     }
     if ( $tree_root->id ) {
         $self->get_document->index_node_by_id( $tree_root->id, undef );
@@ -142,33 +124,21 @@ sub get_tree {
 
 sub get_atree {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->get_tree('a');
 }
 
 sub get_ttree {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->get_tree('t');
 }
 
 sub get_ntree {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->get_tree('n');
 }
 
 sub get_ptree {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->get_tree('p');
 }
 
@@ -184,41 +154,26 @@ sub has_tree {
 
 sub has_atree {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->has_tree('a');
 }
 
 sub has_ttree {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->has_tree('t');
 }
 
 sub has_ntree {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->has_tree('n');
 }
 
 sub has_ptree {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->has_tree('p');
 }
 
 sub get_all_trees {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
 
     return grep {defined}
         map     { $self->{trees}->{ $_ . "_tree" }; } qw(a t n p);
@@ -226,9 +181,6 @@ sub get_all_trees {
 
 sub sentence {
     my $self = shift;
-    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
-        pos_validated_list( \@_ );
-    }
     return $self->get_attr('sentence');
 }
 
@@ -241,6 +193,20 @@ sub set_sentence {
     return $self->set_attr( 'sentence', $text );
 }
 
+sub copy {
+    my $self      = shift;
+    my $selector1 = shift;
+
+    # Get the bundle the zone is in.
+    my $bundle = $self->get_bundle();
+    my $zone1 = $bundle->get_or_create_zone( $self->language(), $selector1 );
+    ### TO DO: copy other trees, too (currently only copies the a-tree)
+    my $aroot0 = $self->get_atree();
+    my $aroot1 = $zone1->create_atree();
+    $aroot0->copy_atree($aroot1);
+    return $zone1;
+}
+
 1;
 
 __END__
@@ -251,11 +217,12 @@ __END__
 
 =head1 NAME
 
-Treex::Core::BundleZone - zone in a bundle containing a sentence and its linguistic representations
 
 =head1 VERSION
 
-version 0.05222
+version 0.06441
+Treex::Core::BundleZone - zone in a bundle containing a sentence and its
+linguistic representations
 
 =head1 SYNOPSIS
 
@@ -275,7 +242,7 @@ translation, test translation).
 
 =head1 ATTRIBUTES
 
-Treex::Core::BundleZone instances have the following attributes:
+C<Treex::Core::BundleZone> instances have the following attributes:
 
 =over 4
 
@@ -287,18 +254,19 @@ Treex::Core::BundleZone instances have the following attributes:
 
 =back
 
-The attributes can be accessed using semi-affordance accessors:
-getters have the same names as attributes, while setters start with
-'set_'. For example by getter C<sentence()> and setter C<set_sentence($sentence)>
+The attributes can be accessed using semi-affordance accessors: getters have
+the same names as attributes, while setters start with C<set_>. For example,
+the attribute C<sentence> has a getter C<sentence()> and a setter
+C<set_sentence($sentence)>
 
 
 =head1 METHODS
 
 =head2 Construction
 
-Treex::Core::BundleZone instances should not be created by the constructor,
+C<Treex::Core::BundleZone> instances should not be created by the constructor,
 but should be created exclusively by calling one of the following methods
-of the embedding  Treex::Core::Bundle instance:
+of the embedding  L<Treex::Core::Bundle> instance:
 
 =over 4
 
@@ -312,8 +280,8 @@ of the embedding  Treex::Core::Bundle instance:
 =head2 Access to trees
 
 There are four types of linguistic trees distinguished in Treex, each of them represented
-by one letter: a - analytical treex, t - tectogrammatical trees, p - phrase-structure trees,
-n - named entity trees. You can create trees by following methods:
+by one letter: I<a> - analytical treex, I<t> - tectogrammatical trees, I<p> - phrase-structure trees,
+I<n> - named entity trees. You can create trees by following methods:
 
 =over 4
 
@@ -381,11 +349,22 @@ You can remove trees by
 
 =item $bundle = $zone->get_bundle();
 
-returns the Treex::Core::Bundle instance which the zone belongs to
+returns the L<Treex::Core::Bundle> instance which the zone belongs to
 
 =item $doc = $zone->get_document();
 
-returns the Treex::Core::Document instance which the zone belongs to
+returns the L<Treex::Core::Document> instance which the zone belongs to
+
+=back
+
+
+=head2 Other
+
+=over 4
+
+=item $zone1 = $zone0->copy($selector1);
+
+creates a copy of the zone (currently copies only the a-tree) under the same language and a new selector
 
 =back
 
