@@ -1,6 +1,6 @@
 package Treex::Core::DocumentReader::ZoneReader;
-{
-  $Treex::Core::DocumentReader::ZoneReader::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::DocumentReader::ZoneReader::VERSION = '0.06441';
 }
 use Moose;
 use Treex::Core::Common;
@@ -9,11 +9,11 @@ use File::Slurp;
 
 has language => (
     is       => 'ro',
-    isa      => 'Treex::Type::LangCode',
+    isa      => 'LangCode',
     required => 1,
 );
 
-has selector => ( isa => 'Treex::Type::Selector', is => 'ro', default => '' );
+has selector => ( isa => 'Selector', is => 'ro', default => '' );
 
 sub zone_label {
     my ($self) = @_;
