@@ -1,6 +1,6 @@
 package Treex::Core::Run;
 BEGIN {
-  $Treex::Core::Run::VERSION = '0.05222';
+  $Treex::Core::Run::VERSION = '0.06441';
 }
 use strict;
 use warnings;
@@ -12,6 +12,7 @@ with 'MooseX::Getopt';
 
 use Cwd;
 use File::Path;
+use File::Temp qw(tempdir);
 use List::MoreUtils qw(first_index);
 use Exporter;
 use base 'Exporter';
@@ -99,7 +100,9 @@ has 'glob' => (
 
 has 'scenario' => (
     traits        => ['NoGetopt'],
-    is            => 'rw', isa => 'Treex::Core::Scenario',
+    is            => 'rw',
+    isa           => 'Treex::Core::Scenario',
+    predicate     => '_has_scenario',
     documentation => 'scenario object',
 );
 
@@ -157,18 +160,6 @@ has 'watch' => (
     documentation => 're-run when the given file is changed TODO better doc',
 );
 
-has 'command' => (
-    is            => 'rw',
-    traits        => ['NoGetopt'],
-    documentation => 'Command by which treex was executed (if executed from command line)',
-);
-
-has 'argv' => (
-    is            => 'rw',
-    traits        => ['NoGetopt'],
-    documentation => 'reference to @ARGV (if executed from command line)',
-);
-
 has 'workdir' => (
     is            => 'rw',
     traits        => ['Getopt'],
@@ -193,6 +184,14 @@ has 'dump_scenario' => (
     documentation => 'Just dump (print to STDOUT) the given scenario and exit.',
 );
 
+has 'survive' => (
+    traits        => ['Getopt'],
+    is            => 'rw',
+    isa           => 'Bool',
+    default       => 0,
+    documentation => 'Continue collecting jobs\' outputs even if some of them crashed (risky, use with care!).',
+);
+
 sub _usage_format {
     return "usage: %c %o scenario [-- treex_files]\nscenario is a sequence of blocks or *.scen files\noptions:";
 }
@@ -222,7 +221,7 @@ sub BUILD {
     }
 
     # 'require' can't be changed to 'imply', since the number of jobs has a default value
-    if ( ( $self->qsub or $self->jobindex ) and not $self->parallel ) {
+    if ( ( $self->qsub || $self->jobindex ) && !$self->parallel ) {
         log_fatal "Options --qsub and --jobindex require --parallel";
     }
     return;
@@ -231,10 +230,21 @@ sub BUILD {
 sub _execute {
     my ($self) = @_;
     if ( $self->dump_scenario ) {
+
+        # TODO: execute_locally does the same work as the following line in a more safe ways
+        # (If someone wants to run treex -d My::Block my_scen.scen)
         my $scen_str = join ' ', @{ $self->extra_argv };
-        my @block_items = Treex::Core::Scenario::parse_scenario_string($scen_str);
+        $self->set_scenario( Treex::Core::Scenario->new( scenario_string => $scen_str ) );
+
+        # TODO: Do it properly - perhaps, add a Scenario option to not load all the blocks.
+        # We cannot create the real scenario instance without loading all the blocks
+        # However, since r6307 some Scenario's functions were changed to methods, so we must create a dummy instance.
+
+        #my @block_items = Treex::Core::Scenario::parse_scenario_string($scen_str);
+        #my @block_items = $dummy_scenario->parse_scenario_string($scen_str);
+
         print "# Full Scenario generated by 'treex --dump_scenario' on " . localtime() . "\n";
-        print Treex::Core::Scenario::construct_scenario_string( \@block_items, 1 ), "\n";
+        print $self->scenario->construct_scenario_string( multiline => 1 ), "\n";
         exit;
     }
 
@@ -248,7 +258,7 @@ sub _execute {
     }
 
     while ( !$done ) {
-        if ( $self->parallel and not defined $self->jobindex ) {
+        if ( $self->parallel && !defined $self->jobindex ) {
             log_info "Parallelized execution. This process is the head coordinating "
                 . $self->jobs . " server processes.";
             $self->_execute_on_cluster();
@@ -298,6 +308,7 @@ my %READER_FOR = (
 );
 
 sub _get_reader_name_for {
+    my $self = shift;
     my ( $ext, @extensions ) = map {/[^.]+\.(.+)?/} @_;
     log_fatal 'Files (' . join( ',', @_ ) . ') must have extensions' if !$ext;
     log_fatal 'All files (' . join( ',', @_ ) . ') must have the same extension' if any { $_ ne $ext } @extensions;
@@ -310,16 +321,19 @@ sub _get_reader_name_for {
 sub _execute_locally {
     my ($self) = @_;
 
-    # Parameters can contain spaces that should be preserved
-    my $scen_str = join ' ',
-        map {
-        if ( my ( $name, $value ) = /(\S+)=(.+ .+)$/ ) {
-            $value =~ s/'/\\'/;
-            qq($name='$value');
+    # Parameters can contain whitespaces that should be preserved
+    my @arguments;
+    foreach my $arg ( @{ $self->extra_argv } ) {
+        if ( $arg =~ /(\S+)=(.+\s.+)$/ ) {
+            my ( $name, $value ) = ( $1, $2 );
+            $value =~ s/'/\\'/g;
+            push @arguments, qq($name='$value');
         }
-        else {$_}
+        else {
+            push @arguments, $arg;
         }
-        @{ $self->extra_argv };
+    }
+    my $scen_str = join ' ', @arguments;
 
     # input data files can be specified in different ways
     if ( $self->glob ) {
@@ -344,7 +358,7 @@ sub _execute_locally {
 
     # some command line options are just shortcuts for blocks; the blocks are added to the scenario now
     if ( $self->filenames ) {
-        my $reader = _get_reader_name_for( @{ $self->filenames } );
+        my $reader = $self->_get_reader_name_for( @{ $self->filenames } );
         log_info "Block $reader added to the beginning of the scenario.";
         $scen_str = "$reader from=" . join( ',', @{ $self->filenames } ) . " $scen_str";
     }
@@ -363,13 +377,14 @@ sub _execute_locally {
     }
 
     my $loading_started = time;
-    my $scenario        = $self->scenario;
-    if ( !defined $scenario ) {
-        $scenario = Treex::Core::Scenario->new( { from_string => $scen_str } );
+    if ( $self->_has_scenario ) {
+        $self->scenario->restart();
     }
     else {
-        $scenario->restart();
+        $self->set_scenario( Treex::Core::Scenario->new( from_string => $scen_str ) );
+        $self->scenario->load_blocks;
     }
+    my $scenario      = $self->scenario;
     my $loading_ended = time;
     log_info "Loading the scenario took " . ( $loading_ended - $loading_started ) . " seconds";
 
@@ -392,8 +407,7 @@ sub _execute_locally {
         }
     }
 
-    $self->set_scenario($scenario);
-    $self->scenario->run();
+    $scenario->run();
     log_info "Running the scenario took " . ( time - $loading_ended ) . " seconds";
 
     if ( $self->jobindex && $self->jobindex == 1 && !$number_of_docs ) {
@@ -447,6 +461,21 @@ sub _create_job_scripts {
     my ($self)      = @_;
     my $current_dir = Cwd::cwd;
     my $workdir     = $self->workdir;
+
+    # If there is some stdin piped to treex we must save it to a file
+    # and redirect it to the jobs.
+    # You cannot use interactive input from terminal to "treex -p".
+    # (If you really need it, use perl -npe 1 | treex -p ...)
+    my $input = '';
+    if ( !-t STDIN ) {
+        my $stdin_file = "$workdir/input";
+        $input = "cat $stdin_file | ";
+        open my $TEMP, '>', $stdin_file;
+        while (<STDIN>) {
+            print $TEMP $_;
+        }
+    }
+
     foreach my $jobnumber ( map { sprintf( "%03d", $_ ) } 1 .. $self->jobs ) {
         my $script_filename = "scripts/job$jobnumber.sh";
         open my $J, ">", "$workdir/$script_filename" or log_fatal $!;
@@ -456,9 +485,11 @@ sub _create_job_scripts {
         print $J "source " . Treex::Core::Config::lib_core_dir()
             . "/../../../../config/init_devel_environ.sh 2> /dev/null\n\n";    # temporary hack !!!
 
-        # TODO: if the original line contains -- file.treex, this doesn't work
-        print $J "treex --jobindex=$jobnumber --outdir=$workdir/output "
-            . ( join " ", map { _quote_argument($_) } @{ $self->argv } )
+        my $opts_and_scen = join ' ', map { _quote_argument($_) } @{ $self->ARGV };
+        if ( $self->filenames ) {
+            $opts_and_scen .= ' -- ' . join ' ', map { _quote_argument($_) } @{ $self->filenames };
+        }
+        print $J $input . "treex --jobindex=$jobnumber --outdir=$workdir/output $opts_and_scen"
             . " 2>> $workdir/output/job$jobnumber.started\n\n";
         print $J "touch $workdir/output/job$jobnumber.finished\n";
         close $J;
@@ -534,14 +565,22 @@ sub _run_job_scripts {
     return;
 }
 
+# Prints error messages from the output of the current document processing.
 sub _print_output_files {
     my ( $self, $doc_number ) = @_;
+
     foreach my $stream (qw(stderr stdout)) {
         my $mask = $self->workdir . "/output/job*-doc" . sprintf( "%07d", $doc_number ) . ".$stream";
         my ($filename) = glob $mask;
-
         if ( !defined $filename ) {
-            log_fatal "Document $doc_number finished without producing $mask";
+            my $message = "Document $doc_number finished without producing $mask";
+            if ( $self->survive ) {
+                log_warn("$message (fatal error ignored due to survival mode, be careful)");
+                return;
+            }
+            else {
+                log_fatal $message;
+            }
         }
 
         open my $FILE, '<:utf8', $filename or log_fatal $!;
@@ -552,18 +591,30 @@ sub _print_output_files {
         }
         else {
             my ($jobnumber) = ( $filename =~ /job(...)/ );
-            my $report = $self->forward_error_level;
+            my $report      = $self->forward_error_level;
+            my $success     = 0;
             while (<$FILE>) {
 
+                # skip [success] indicatory lines, but set the success flag to 1
+                if ( $_ =~ /^Document [0-9]+\/[0-9]+ .*: \[success\]\.\r?\n?$/ ) {
+                    $success = 1;
+                    next;
+                }
+
                 #TODO: better implementation
                 # $Treex::Core::Log::ERROR_LEVEL_VALUE{$report} doesn't work
-                my ( undef, $level ) = /^(TMT|TREEX)-(DEBUG|INFO|WARN|FATAL)/;
+                my ($level) = /^TREEX-(DEBUG|INFO|WARN|FATAL)/;
                 $level ||= '';
                 next if $level =~ /^D/ && $report !~ /^[AD]/;
                 next if $level =~ /^I/ && $report !~ /^[ADI]/;
                 next if $level =~ /^W/ && $report !~ /^[ADIW]/;
                 print STDERR "job$jobnumber: $_";
             }
+
+            # test for the [success] indication on the last line of STDERR
+            if ( !$success ) {
+                log_fatal "Document $doc_number has not finished successfully";
+            }
         }
         close $FILE;
     }
@@ -622,8 +673,16 @@ sub _wait_for_jobs {
 
 sub _check_job_errors {
     my ($self) = @_;
-    if ( glob $self->workdir . '/output/*fatalerror' ) {
-        log_info 'At least one job crashed with fatal error. All remaining jobs will be interrupted now.';
+    my $workdir = $self->workdir;
+    if ( defined( my $fatal_name = glob "$workdir/output/*fatalerror" ) ) {
+        log_info "At least one job crashed with fatal error ($fatal_name).";
+        my ($fatal_job) = $fatal_name =~ /job(\d+)/;
+        my $command     = "grep -h -A 10 -B 25 FATAL $workdir/output/job$fatal_job*.stderr";
+        my $fatal_lines = qx($command);
+        log_info "********************** FATAL ERRORS FOUND IN JOB $fatal_job ******************\n";
+        log_info "$fatal_lines\n";
+        log_info "********************** END OF JOB $fatal_job FATAL ERRORS LOG ****************\n";
+        log_info "All remaining jobs will be interrupted now.";
         $self->_delete_jobs_and_exit;
     }
     return;
@@ -632,8 +691,8 @@ sub _check_job_errors {
 sub _delete_jobs_and_exit {
     my ($self) = @_;
 
+    log_info "Deleting jobs: " . join( ', ', @{ $self->sge_job_numbers } );
     foreach my $job ( @{ $self->sge_job_numbers } ) {
-        log_info "Deleting job $job";
         system "qdel $job";
     }
     log_info 'You may want to inspect generated files in ' . $self->workdir . '/output/';
@@ -646,10 +705,11 @@ sub _execute_on_cluster {
     # create working directory, if not specified as a command line option
     if ( not defined $self->workdir ) {
         my $counter;
-        my $directory;
+        my $directory_prefix;
+        my @existing_dirs;
         do {
             $counter++;
-            $directory = sprintf "%03d-cluster-run", $counter;
+            $directory_prefix = sprintf "%03d-cluster-run-", $counter;
 
             # TODO There is a strange problem when executing e.g.
             #  for i in `seq 4`; do treex/bin/t/qparallel.t; done
@@ -657,11 +717,15 @@ sub _execute_on_cluster {
             # I don't know the real cause of the bug, but as a workaround
             # you can omit --cleanup or uncomment next line
             # $directory .= sprintf "%03d-cluster-run", rand 1000;
+            #            print STDERR "XXXX tested prefix $directory_prefix:".(join ' ', glob("$directory_prefix*"))."\n";
+            @existing_dirs = glob "$directory_prefix*";    # separate var because of troubles with glob context
             }
-            while ( -d $directory );
+            while (@existing_dirs);
+        my $directory = tempdir "${directory_prefix}XXXXX" or log_fatal($!);
         $self->set_workdir($directory);
-        log_info "Creating working directory $directory";
-        mkdir $directory or log_fatal $!;
+        log_info "Working directory $directory created";
+
+        #        mkdir $directory or log_fatal $!;
     }
 
     foreach my $subdir (qw(output scripts)) {
@@ -715,27 +779,30 @@ sub _redirect_output {
 
 # not a method !
 sub treex {
-    my $arguments = shift;                                   # ref to array of arguments, or a string containing all arguments as on the command line
 
-    if ( ref($arguments) eq 'ARRAY' ) {
+    # ref to array of arguments, or a string containing all arguments as on the command line
+    my $arguments = shift;
+
+    if ( ref($arguments) eq 'ARRAY' && scalar @$arguments > 0 ) {
         my $idx = first_index { $_ eq '--' } @$arguments;
-        my %args;
-        $args{command} = join " ", @$arguments;
-        $args{argv} = $arguments;
+        my %args = ( argv => $arguments );
         if ( $idx != -1 ) {
-            $args{filenames} = [ splice @$arguments, $idx + 1 ]
+            $args{filenames} = [ splice @$arguments, $idx + 1 ];
+            pop @$arguments;    # delete "--"
         }
         my $runner = Treex::Core::Run->new_with_options( \%args );
         $runner->_execute();
 
     }
 
-    elsif ( defined $arguments ) {
-        treex( [ grep {$_} split( /\s/, $arguments ) ] );
+    elsif ( defined $arguments && ref($arguments) ne 'ARRAY' ) {
+        treex( [ grep { defined $_ && $_ ne '' } split( /\s/, $arguments ) ] );
     }
 
     else {
-        log_fatal 'Unspecified arguments for running treex.';
+        treex('--help');
+
+        #log_fatal 'Unspecified arguments for running treex.';
     }
     return;
 }
@@ -775,7 +842,7 @@ Treex::Core::Run + treex - applying Treex blocks and/or scenarios on data
 
 =head1 VERSION
 
-version 0.05222
+version 0.06441
 
 =head1 SYNOPSIS
 
@@ -792,67 +859,22 @@ In Perl:
 
 =head1 DESCRIPTION
 
-Treex::Core::Run allows to apply a block, a scenario, or their mixture on a set of
-data files. It is designed to be used primarily from bash command line, using
-a thin front-end script called C<treex>. However, the same list of argument can be
-passed by an array reference to the function C<treex()> imported from Treex::Core::Run.
+C<Treex::Core::Run> allows to apply a block, a scenario, or their mixture on a 
+set of data files. It is designed to be used primarily from bash command line, 
+using a thin front-end script called C<treex>. However, the same list of 
+arguments can be passed by an array reference to the function C<treex()> 
+imported from C<Treex::Core::Run>.
 
-Note that this module supports distributed processing, simply by adding switch C<-p>.
-Then there are two ways to process the data in a parallel fashion. By default,
-SGE cluster\'s qsub is expected to be available. If you have no cluster but want
-to make the computation parallelized at least on a multicore machine, add the C<--local>
-switch.
+Note that this module supports distributed processing, simply by adding switch 
+C<-p>. Then there are two ways to process the data in a parallel fashion. By 
+default, SGE cluster\'s C<qsub> is expected to be available. If you have no 
+cluster but want to make the computation parallelized at least on a multicore 
+machine, add the C<--local> switch.
 
 =head1 USAGE
 
- usage: treex [-?dEegjLlpqSs] [long options...] scenario [-- treex_files]
- scenario is a sequence of blocks or *.scen files
- options:
- 	-? --usage --help            Prints this usage information.
- 	-s --save                    save all documents
- 	-q --quiet                   Warning, info and debug messages are
- 	                             suppressed. Only fatal errors are
- 	                             reported.
- 	--cleanup                    Delete all temporary files.
- 	-e --error_level             Possible values: ALL, DEBUG, INFO, WARN,
- 	                             FATAL
- 	-E --forward_error_level     messages with this level or higher will
- 	                             be forwarded from the distributed jobs
- 	                             to the main STDERR
- 	-L --language --lang         shortcut for adding "Util::SetGlobal
- 	                             language=xy" at the beginning of the
- 	                             scenario
- 	-S --selector                shortcut for adding "Util::SetGlobal
- 	                             selector=xy" at the beginning of the
- 	                             scenario
- 	-l --filelist                TODO load a list of treex files from a
- 	                             file
- 	-g --glob                    Input file mask whose expansion is to
- 	                             Perl, e.g. --glob '*.treex'
- 	-p --parallel                Parallelize the task on SGE cluster
- 	                             (using qsub).
- 	-j --jobs                    Number of jobs for parallelization,
- 	                             default 10. Requires -p.
- 	--jobindex                   Not to be used manually. If number of
- 	                             jobs is set to J and modulo set to M,
- 	                             only I-th files fulfilling I mod J == M
- 	                             are processed.
- 	--outdir                     Not to be used manually. Dictory for
- 	                             collecting standard and error outputs in
- 	                             parallelized processing.
- 	--qsub                       Additional parameters passed to qsub.
- 	                             Requires -p.
- 	--local                      Run jobs locally (might help with
- 	                             multi-core machines). Requires -p.
- 	--watch                      re-run when the given file is changed
- 	                             TODO better doc
- 	--workdir                    working directory for temporary files in
- 	                             parallelized processing (if not
- 	                             specified, directories such as
- 	                             001-cluster-run, 002-cluster-run etc.
- 	                             are created)
- 	-d --dump_scenario           Just dump (print to STDOUT) the given
- 	                             scenario and exit.
+ Can't locate Treex/Core/Run.pm in @INC (@INC contains: /usr/lib/perl5/site_perl/5.12.3/x86_64-linux-thread-multi /usr/lib/perl5/site_perl/5.12.3 /usr/lib/perl5/vendor_perl/5.12.3/x86_64-linux-thread-multi /usr/lib/perl5/vendor_perl/5.12.3 /usr/lib/perl5/5.12.3/x86_64-linux-thread-multi /usr/lib/perl5/5.12.3 .) at bin/treex line 5.
+ BEGIN failed--compilation aborted at bin/treex line 5.
 
 =head1 AUTHOR
 
