@@ -1,6 +1,6 @@
 package Treex::Core::TredView::Colors;
-{
-  $Treex::Core::TredView::Colors::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::TredView::Colors::VERSION = '0.06441';
 }
 
 use Moose;
@@ -17,7 +17,7 @@ sub _build_colors {
         'edge'      => '#555555',
         'coord'     => '#bbbbbb',
         'error'     => '#ff0000',
-        'coord_mod' => 'aquamarine4',
+        'coord_mod' => '#666666',
 
         'anode'            => '#ff6666',
         'anode_coord'      => '#ff6666',
@@ -25,7 +25,6 @@ sub _build_colors {
         'tnode'            => '#4488ff',
         'tnode_coord'      => '#ccddff',
         'terminal'         => '#ffff66',
-        'terminal_head'    => '#90ee90',
         'nonterminal_head' => '#90ee90',
         'nonterminal'      => '#ffffe0',
         'trace'            => '#aaaaaa',
@@ -35,7 +34,6 @@ sub _build_colors {
         'coref_text' => '#4c509f',
         'compl'      => '#629f52',
         'alignment'  => '#bebebe',
-        'coindex'    => '#ffa500', #orange
 
         'lex'         => '#006400',
         'aux'         => '#ff8c00',
@@ -47,20 +45,17 @@ sub _build_colors {
         'nodetype'    => '#00008b',
         'sempos'      => '#8b008b',
         'phrase'      => '#00008b',
-        'formeme'     => '#b000b0',
-        'tag'         => '#004048',
-        'tag_feat'    => '#7098A0',
 
-        'clause0' => '#ff00ff',         #magenta
-        'clause1' => '#ffa500',         #orange
-        'clause2' => '#0000ff',         #blue
-        'clause3' => '#3cb371',         #MediumSeaGreen
-        'clause4' => '#ff0000',         #red
-        'clause5' => '#9932cc',         #DarkOrchid
-        'clause6' => '#00008b',         #DarkBlue
-        'clause7' => '#006400',         #DarkGreen
-        'clause8' => '#8b0000',         #DarkRed
-        'clause9' => '#008b8b',         #DarkCyan
+        'clause0' => 'magenta',
+        'clause1' => 'orange',
+        'clause2' => 'blue',
+        'clause3' => 'green',
+        'clause4' => 'red',
+        'clause5' => 'DarkOrange',
+        'clause6' => 'DarkBlue',
+        'clause7' => 'DarkGreen',
+        'clause8' => 'DarkRed',
+        'clause9' => 'DarkCyan',
     };
 }
 
