@@ -1,6 +1,6 @@
 package Treex::Core::TredView::Styles;
-{
-  $Treex::Core::TredView::Styles::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::TredView::Styles::VERSION = '0.06441';
 }
 
 use Moose;
@@ -89,50 +89,38 @@ sub _tnode_style {
     my $x2 = 'xn-(xn-xp)*' . $k2;
     my $y2 = 'yn-(yn-yp)*' . $k2;
 
-    my $line_width = 2;
-    my $line_color = $self->_colors->get('edge');
-    my $line_coords;
-    my $line_dash;
-
-    if ($node->{is_member}) {
-        if (not $node->is_root and $self->_is_coord($node->parent)) {
-            $line_width = 1;
-            $line_color = $self->_colors->get('coord');
-        } else {
-            $line_color = $self->_colors->get('error');
+    if (( $node->{functor} and $node->{functor} =~ m/^(?:PAR|PARTL|VOCAT|RHEM|CM|FPHR|PREC)$/ )
+        or
+        ( not $node->is_root and $node->parent->is_root )
+        )
+    {
+        $style .= '#{Line-width:1}#{Line-dash:2,4}';
+    }
+    if ( $node->{is_member} ) {
+        if ( $self->_is_coord($node) and $self->_is_coord( $node->parent ) ) {
+            $style .= "#{Line-coords:n,n,n,n&$x1,$y1,$x2,$y2}" . $coord_circle;
+            $style .= '#{Line-width:0&1}#{Line-fill:white&' . $self->_colors->get('coord') . '}';
+        }
+        elsif ( not $node->is_root and $self->_is_coord( $node->parent ) ) {
+            $style .= "#{Line-coords:n,n,$x2,$y2}#{Line-width:1}";
+            $style .= '#{Line-fill:' . $self->_colors->get('coord') . '}';
+        }
+        else {
+            $style .= '#{Line-fill:' . $self->_colors->get('error') . '}';
         }
-    } elsif (not $node->is_root and $self->_is_coord($node->parent)) {
-        $line_color = $self->_colors->get('coord_mod');
-    } elsif ($self->_is_coord($node)) {
-        $line_color = $self->_colors->get('coord');
-        $line_width = 1;
     }
-
-    if (($node->{functor} and $node->{functor} =~ m/^(?:PAR|PARTL|VOCAT|RHEM|CM|FPHR|PREC)$/) or (not $node->is_root and $node->parent->is_root)) {
-        $line_width = 1;
-        $line_dash = '2,4';
-        $line_color = $self->_colors->get('edge');
+    elsif ( not $node->is_root and not $node->parent->is_root and $self->_is_coord( $node->parent ) ) {
+        $style .= "#{Line-coords:n,n,$x2,$y2}#{Line-fill:" . $self->_colors->get('coord_mod') . '}';
     }
-
-    if ($self->_is_coord($node)) {
-        $line_coords = "n,n,n,n&$x1,$y1";
-        $line_width = '0&'.$line_width;
-        $line_color = 'white&'.$line_color;
-        $line_dash = '&'.$line_dash if $line_dash;
-    } else {
-        $line_coords = 'n,n';
+    elsif ( $self->_is_coord($node) ) {
+        $style .= $coord_circle . "#{Line-coords:n,n,n,n&$x1,$y1,p,p}";
+        $style .= '#{Line-width:0&1}#{Line-fill:white&' . $self->_colors->get('coord') . '}';
+        $style .= '#{Line-dash:&2,4}' if $node->parent->is_root;
     }
-
-    if (not $node->is_root and $self->_is_coord($node->parent)) {
-        $line_coords .= ",$x2,$y2";
-    } else {
-        $line_coords .= ',p,p';
+    else {
+        $style .= '';
     }
 
-    $style .= $coord_circle if $self->_is_coord($node);
-    $style .= "#{Line-width:$line_width}#{Line-fill:$line_color}#{Line-coords:$line_coords}";
-    $style .= "#{Line-dash:$line_dash}" if $line_dash;
-
     return $style;
 }
 
@@ -144,7 +132,7 @@ sub _nnode_style {
 sub _pnode_style {
     my ( $self, $node ) = @_;
 
-    my $terminal = $node->is_leaf;
+    my $terminal = $node->get_pml_type_name eq 'p-terminal.type' ? 1 : 0;
 
     my $style = '#{Line-coords:n,n,n,p,p,p}';
     $style .= '#{nodeXSkip:4}#{nodeYSkip:0}#{NodeLabel-skipempty:1}';
@@ -166,10 +154,7 @@ sub _pnode_style {
     }
     else {
         $style .= '#{Line-dash:.}';
-        my $ctype = $node->tag eq '-NONE-' ? 'trace'
-                  : $node->is_head         ? 'terminal_head'
-                  :                          'terminal';
-        $style .= '#{Oval-fill:' . $self->_colors->get($ctype) . '}';
+        $style .= '#{Oval-fill:' . ( $node->{tag} eq '-NONE-' ? $self->_colors->get('trace') : $self->_colors->get('terminal') ) . '}';
     }
 
     return $style;
@@ -210,11 +195,6 @@ sub draw_arrows {
                 $EX = "x$T+($MX-x$T)*$K2";
                 $EY = "y$T+($MY-y$T)*$K2";
             }
-            if ( $arrow_type eq 'coindex' ) {
-                $MX = "((x$T+xn)/2 + $Y*(25/$D+0.12))";
-                $MY = "((y$T+6+yn)/2 - $X*(25/$D+0.12))";
-                $EY = "y$T+6";
-            }
 
             push @coords, "$BX,$BY,$MX,$MY,$EX,$EY";
         }
@@ -274,7 +254,7 @@ Treex::Core::TredView::Styles - Styling of trees in Tred (how they look)
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.06441
 
 =head1 DESCRIPTION
 
@@ -296,8 +276,6 @@ This packages provides styling for the trees displayed in Tred.
 
 =head2 Private methods
 
-=over 4
-
 =item _anode_style
 
 =item _tnode_style
@@ -306,7 +284,7 @@ This packages provides styling for the trees displayed in Tred.
 
 =item _pnode_style
 
-=back
+=over 4
 
 =head1 AUTHOR
 
@@ -316,4 +294,4 @@ Josef Toman <toman@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
