@@ -1,6 +1,6 @@
 package Treex::Core::TredView::Vallex;
-{
-  $Treex::Core::TredView::Vallex::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::TredView::Vallex::VERSION = '0.06441';
 }
 
 use Moose;
@@ -24,7 +24,6 @@ sub _extension_missing {
     my $message = "This function requires additional extension that is missing.\n";
     $message .= "Please install extension '$name'.";
     TredMacro::ToplevelFrame->messageBox( -type => 'ok', -message => $message );
-    return;
 }
 
 sub _find_vallex {
@@ -141,14 +140,15 @@ sub _OpenValLexicon_En {
     my $vallex_file = $self->_find_vallex($node);
     return unless $vallex_file;
 
-    my $opts = {
-        -vallex_file => $vallex_file,
-        -lemma       => $node->attr('t_lemma'),
-        -sempos      => $node->attr('gram/sempos'),
-        -frameid     => $node->attr('val_frame.rf')
-    };
-    $opts->{-pos} = $a_node->attr('tag') if $a_node->attr('tag');
-    TrEd::EngValLex::GUI::OpenEditor($opts);
+    TrEd::EngValLex::GUI::OpenEditor(
+        {
+            -vallex_file => $vallex_file,
+            -lemma       => $node->attr('t_lemma'),
+            -sempos      => $node->attr('gram/sempos'),
+            -frameid     => $node->attr('val_frame.rf'),
+            -pos         => $a_node->attr('tag')
+        }
+    );
     TredMacro::ChangingFile(0);
     return;
 }
@@ -188,7 +188,6 @@ sub _OpenValFrameList_Cs {
         }
     );
     TredMacro::ChangingFile(0);
-    return;
 }
 
 sub _OpenValFrameList_En {
@@ -215,20 +214,20 @@ sub _OpenValFrameList_En {
     my $vallex_file = $self->_find_vallex($node);
     return unless $vallex_file;
 
-    my $opts = {
-        -withdraw    => 1,
-        -vallex_file => $vallex_file,
-        -lemma       => $node->{t_lemma} || undef,
-        -sempos      => $node->attr('gram/sempos') || undef,
-        -lemma_attr  => 't_lemma',
-        -sempos_attr => 'gram/sempos',
-        -frameid     => $node->attr('val_frame.rf'),
-        -assignfunc  => sub { }
-    };
-    $opts->{-pos} = $a_node->attr('tag') if $a_node->attr('tag');
-    TrEd::EngValLex::GUI::ChooseFrame($opts);
+    TrEd::EngValLex::GUI::ChooseFrame(
+        {
+            -withdraw    => 1,
+            -vallex_file => $vallex_file,
+            -lemma       => $node->{t_lemma} || undef,
+            -sempos      => $node->attr('gram/sempos') || undef,
+            -lemma_attr  => 't_lemma',
+            -sempos_attr => 'gram/sempos',
+            -frameid     => $node->attr('val_frame.rf'),
+            -assignfunc  => sub { },
+            -pos         => $a_node->attr('tag')
+        }
+    );
     TredMacro::ChangingFile(0);
-    return;
 }
 
 1;
@@ -237,15 +236,15 @@ __END__
 
 =head1 NAME
 
-Treex::Core::TredView::Vallex - Browsing valency lexicons
+Treex::Core::TredView::Vallex - Browsing vallency lexicons
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.06441
 
 =head1 DESCRIPTION
 
-This package provides browsers of valency lexicons
+This packages provides browsers of vallency lexicons
 
 =head1 METHODS
 
@@ -261,8 +260,6 @@ This package provides browsers of valency lexicons
 
 =head2 Private methods
 
-=over 4
-
 =item _OpenValLexicon_Cs
 
 =item _ChooseValFrame_Cs
@@ -277,7 +274,7 @@ This package provides browsers of valency lexicons
 
 =item _assigned_frame_pos_of
 
-=back
+=over 4
 
 =head1 AUTHOR
 
@@ -287,4 +284,4 @@ Josef Toman <toman@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
